import { Component, Prop, h } from '@stencil/core';
export class Button {
  constructor() {
    /**
     * The text label that appears on the button.
     */
    this.label = 'Primary Button';
    /**
     * The purpose of the button.
     */
    this.type = 'primary';
  }
  render() {
    const iconName = this.type == 'destructive' ? 'destroy' : this.icon ? this.icon : null;
    return (h("button", { ref: this.ref, name: this.name, class: [...getSharedStyles(), ...getStyleForType(this.type)].join(' ') },
      iconName && h("cosmos-icon", { name: iconName, size: "m" }),
      h("span", null, this.label)));
  }
  static get is() { return "cosmos-button"; }
  static get properties() { return {
    "ref": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "A reference to the internal element"
      },
      "attribute": "ref",
      "reflect": false
    },
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The unique name of the button"
      },
      "attribute": "name",
      "reflect": false
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The text label that appears on the button."
      },
      "attribute": "label",
      "reflect": false,
      "defaultValue": "'Primary Button'"
    },
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ButtonType",
        "resolved": "\"destructive\" | \"minimal\" | \"primary\" | \"secondary\"",
        "references": {
          "ButtonType": {
            "location": "import",
            "path": "./types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The purpose of the button."
      },
      "attribute": "type",
      "reflect": false,
      "defaultValue": "'primary'"
    },
    "icon": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "IconName",
        "resolved": "string",
        "references": {
          "IconName": {
            "location": "import",
            "path": "../cosmos-icon/types"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Name of one of our icon presets"
      },
      "attribute": "icon",
      "reflect": false
    }
  }; }
}
function getSharedStyles() {
  return ['flex', 'flex-row', 'items-center', 'space-x-3', 'text-2', 'font-sans', 'font-bold', 'whitespace-nowrap', 'h-8', 'rounded', 'focus:outline'];
}
function getStyleForType(type) {
  if (type == 'primary') {
    return getPrimaryStyle();
  }
  if (type == 'secondary') {
    return getSecondaryStyle();
  }
  if (type == 'minimal') {
    return getMinimalStyle();
  }
  if (type == 'destructive') {
    return getDestructiveStyle();
  }
}
function getPrimaryStyle() {
  return [
    'px-4',
    'shadow-1',
    'text-shadow',
    'relative',
    'text-action-primary-foreground',
    'bg-action-primary-background',
    'hover:text-action-primary-foreground-hover',
    'hover:bg-action-primary-background-hover',
    'active:top-0.5',
    'active:text-action-primary-foreground-active',
    'active:bg-action-primary-background-active',
    'active:shadow-none',
  ];
}
function getDestructiveStyle() {
  return [
    'px-4',
    'relative',
    'text-shadow',
    'bg-action-destructive-background',
    'hover:bg-action-destructive-background-hover',
    'active:bg-action-destructive-background-active',
    'text-action-destructive-foreground',
    'hover:text-action-destructive-foreground-hover',
    'active:text-action-destructive-foreground-active',
  ];
}
function getSecondaryStyle() {
  return [
    'px-4',
    'text-action-secondary-foreground',
    'hover:text-action-secondary-foreground-hover',
    'active:text-action-secondary-foreground-active',
    'bg-action-secondary-background',
    'hover:bg-action-secondary-background-hover',
    'active:bg-action-secondary-background-active',
  ];
}
function getMinimalStyle() {
  return [
    'px-3',
    'bg-action-minimal-background',
    'hover:bg-action-minimal-background-hover',
    'active:bg-action-minimal-background-active',
    'text-action-minimal-foreground',
    'hover:text-action-minimal-foreground-hover',
    'active:action-minimal-foreground-active',
  ];
}
