import { Component, Prop, h } from '@stencil/core';
export class FormLabel {
  constructor() {
    /**
     * The text content of the label
     */
    this.text = 'Form Label';
    /**
     * Is the control that is associated with this label disabled?
     */
    this.disabled = false;
    /**
     * Show a visual indicator if the input that the label represents is required
     */
    this.required = false;
  }
  render() {
    return (h("label", { htmlFor: this.for, class: getStyleClasses(this.for, this.disabled) },
      h("span", null, this.text),
      this.required == true && h("span", { class: 'text-signal-warning ml-2', title: 'Required' }, "*")));
  }
  static get is() { return "cosmos-form-label"; }
  static get properties() { return {
    "text": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The text content of the label"
      },
      "attribute": "text",
      "reflect": false,
      "defaultValue": "'Form Label'"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is the control that is associated with this label disabled?"
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "for": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The id of the labeled control"
      },
      "attribute": "for",
      "reflect": false
    },
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Show a visual indicator if the input that the label represents is required"
      },
      "attribute": "required",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
}
function getStyleClasses(forElement, disabled) {
  return [
    ...(forElement !== null ? ['cursor-pointer'] : []),
    'text-2',
    'font-bold',
    disabled ? 'color-text-subtle' : 'color-text-default'
  ].join(' ');
}
