import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
import { fetchIcon } from './utils';
import * as iconMap from './assets/icon-map.json';
export class Icon {
  constructor() {
    /**
     * Which size preset the icon uses
     */
    this.size = 'm';
  }
  connectedCallback() {
    this.loadIcon();
  }
  async loadIcon() {
    try {
      // TODO(harry): Do we need to modify any attributes here before using
      // the SVG? i.e Add `focusable="false"` to prevent IE from allowing
      // it to gain focus
      this.svg = await fetchIcon(this.name, this.size, iconMap);
    }
    catch (e) {
      console.error(e);
    }
  }
  render() {
    const sizeClasses = getClassesForSize(this.size);
    return (h(Host, { role: "img", class: `inline-flex items-center justify-center  ${sizeClasses[0]} ${sizeClasses[1]}` },
      h("span", { class: `icon-inner fill-current inline-block ${this.color ? this.color : 'text-current'} ${sizeClasses[0]} ${sizeClasses[1]}`, innerHTML: this.svg || null })));
  }
  static get is() { return "cosmos-icon"; }
  static get originalStyleUrls() { return {
    "$": ["cosmos-icon.css"]
  }; }
  static get styleUrls() { return {
    "$": ["cosmos-icon.css"]
  }; }
  static get assetsDirs() { return ["assets"]; }
  static get properties() { return {
    "name": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "IconName",
        "resolved": "string",
        "references": {
          "IconName": {
            "location": "import",
            "path": "./types"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Semantic name from our fixed list of possible icons"
      },
      "attribute": "name",
      "reflect": false
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "IconSize",
        "resolved": "\"l\" | \"m\" | \"s\"",
        "references": {
          "IconSize": {
            "location": "import",
            "path": "./types"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Which size preset the icon uses"
      },
      "attribute": "size",
      "reflect": false,
      "defaultValue": "'m'"
    },
    "color": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The color of the icon. This value should be the name of one of our color palette tokens"
      },
      "attribute": "color",
      "reflect": false
    }
  }; }
  static get states() { return {
    "svg": {}
  }; }
  static get watchers() { return [{
      "propName": "name",
      "methodName": "loadIcon"
    }, {
      "propName": "size",
      "methodName": "loadIcon"
    }]; }
}
// UTILITIES
function getClassesForSize(size) {
  // IMPORTANT(harry): We have to use the full tailwind
  // class names here instead of building them dynamicaly
  // so the classes aren't purged by PurgeCSS
  switch (size) {
    case 's':
      return ['w-4', 'h-4'];
    case 'm':
      return ['w-5', 'h-5'];
    case 'l':
      return ['w-6', 'h-6'];
  }
}
