import { getAssetPath } from '@stencil/core';
const requests = new Map();
export function getIconPath(name, style) {
  return getAssetPath(`assets/svg/${style}/${name}.svg`);
}
export async function fetchIcon(name, size, iconMap) {
  // We didn't already request it.
  // Find the icon meta data from our icon map
  const iconData = iconMap.icons.find(i => i.name == name);
  if (!iconData) {
    return Promise.reject(new Error(`Icon does not exist: ${name}`));
  }
  // The icon data exists, so grab the filename
  // and see if we can fetch the actual SVG
  const iconPath = getIconPath(iconData.fileName, iconData.styles[size]);
  // See if we've already requested this icon file
  let request = requests.get(iconPath);
  if (request) {
    console.log(`Icon "${name}" already requested. Re-using`, request);
    return request;
  }
  request = fetch(iconPath).then(async (response) => {
    if (response.ok) {
      return response.text();
    }
    return Promise.reject(new Error(`Failed to fetch icon SVG file – ${response.status} ${response.statusText}`));
  });
  // Cache the request
  requests.set(iconPath, request);
  return request;
}
